# Powershell script by Michal Hompus, http://blog.hompus.nl

# STSADM -o setapppassword -password <password>

function SetAppPassword([String]$password) {
	$type = [Microsoft.SharePoint.Utilities.SPPropertyBag].Assembly.GetType("Microsoft.SharePoint.Utilities.SPSecureString")
	$method = $type.GetMethod("FromString", "Static, NonPublic", $null, @([String]), $null)
	$secureString = $method.Invoke($null, @($password))
	[Microsoft.SharePoint.SPSecurity]::SetApplicationCredentialKey($secureString)
}


# STSADM -o setproperty -url <url> -pn "peoplepicker-searchadforests" -pv <trust domain value>

function PeoplePickerSearchADForests([String]$webApplicationUrl, [String]$value) {
	$webApplication = Get-SPWebApplication $webApplicationUrl

	$searchActiveDirectoryDomains = $webApplication.PeoplePickerSettings.SearchActiveDirectoryDomains
	$searchActiveDirectoryDomains.Clear()

	$currentDomain = (Get-WmiObject -Class Win32_ComputerSystem).Domain

	if (![String]::IsNullOrEmpty($value)) {
		$value.Split(@(';'), "RemoveEmptyEntries") | ForEach { 
			$strArray = $_.Split(@(';'))
		
			$item = New-Object Microsoft.SharePoint.Administration.SPPeoplePickerSearchActiveDirectoryDomain
		
			[String]$value = $strArray[0]

			$index = $value.IndexOf(':');
			if ($index -ge 0) {
				$item.DomainName = $value.Substring($index + 1);
			} else {
				$item.DomainName = $value;
			}

			if ([System.Globalization.CultureInfo]::InvariantCulture.CompareInfo.IsPrefix($value, "domain:", "IgnoreCase")) {
				$item.IsForest = $false;
			} else {
				$item.IsForest = $true;
			}

			if ($item.DomainName -ne $currentDomain) {
				$credentials = $host.ui.PromptForCredential("Foreign domain trust credentials", "Please enter the trust credentials to connect to the " + $item.DomainName + " domain", "", "")

				$item.LoginName = $credentials.UserName;
				$item.SetPassword($credentials.Password);
			}
	
			$searchActiveDirectoryDomains.Add($item);
		}

		$webApplication.Update()
	}
}